<html>

<head>
</head>

<body>
    <p> This is the first time we've received a request to send a message to this
        email address ({{email_address}}).
        Please watch your inbox for a confirmation message with a link to click
        in order to confirm that you are the owner of this email account.
        After that we'll get your email out to you quickly.
    </p>
    
</body>

</html>